MultiPlotWidget — pyqtgraph 0.11.0rc0 documentation

# MultiPlotWidget

class `pyqtgraph.` `MultiPlotWidget`(parent=None)

  Widget implementing a graphicsView with a single MultiPlotItem inside.

  `__init__`(parent=None)

    Arguments: |
    parent | Optional parent widget
    useOpenGL | If True, the GraphicsView will use OpenGL to do all of its rendering. This can improve performance on some systems, but may also introduce bugs (the combination of QGraphicsView and QGLWidget is still an ‘experimental’ feature of Qt)
    background | Set the background color of the GraphicsView. Accepts any single argument accepted by `mkColor`. By default, the background color is determined using the ‘backgroundColor’ configuration option (see `setConfigOptions`).

  `close`(self) → bool
  `resizeEvent`(self, event: PySide2.QtGui.QResizeEvent)
  `setMinimumPlotHeight`(min)

    Set the minimum height for each sub-plot displayed.

    If the total height of all plots is greater than the height of the widget, then a scroll bar will appear to provide access to the entire set of plots.

    Added in version 0.9.9